Fits a k-LIME model on predictions produced by a ML model. Provides explanations/reason codes.
h2o.klime(training_frame, x, y, model_id = NULL, max_k = 20,
estimate_k = TRUE, alpha = 0.5, min_cluster_size = 20, seed = -1)Id of the training data frame (Not required, to allow initial validation of model parameters).
A vector containing the names or indices of the predictor variables to use in building the model. If x is missing,then all columns except y are used.
The name of the response variable in the model.If the data does not contain a header, this is the first column index, and increasing from left to right. (The response must be either an integer or a categorical variable).
Destination id for this model; auto-generated if not specified.
Maximum number of clusters to be considered. Defaults to 20.
Logical. Automatically determine the number of clusters in an unsupervised manner. Defaults to TRUE.
Balance between L1 and L2 regularization. Use alpha=0 to switch off L1 variable selection. Defaults to 0.5.
Required minimum cluster size to build a local regression model, smaller clusters will use a global model. Defaults to 20.
Seed for random numbers (affects certain parts of the algo that are stochastic and those might or might not be enabled by default) Defaults to -1 (time-based random number).