Performs a group by and apply similar to ddply.
h2o.group_by(data, by, ..., gb.control = list(na.methods = NULL, col.names =
NULL))an H2OFrame object.
a list of column names
a list of how to handle NA values in the dataset as well as how to name
output columns. See Details: for more help.
any supported aggregate function.
Returns a new H2OFrame object with columns equivalent to the number of groups created
In the case of na.methods within gb.control, there are three possible settings.
"all" will include NAs in computation of functions. "rm" will completely
remove all NA fields. "ignore" will remove NAs from the numerator but keep
the rows for computational purposes. If a list smaller than the number of columns groups is
supplied, the list will be padded by "ignore".
Similar to na.methods, col.names will pad the list with the default column names if
the length is less than the number of colums groups supplied.