h2o.svd(training_frame, x, destination_key, model_id = NULL, validation_frame = NULL, ignore_const_cols = TRUE, score_each_iteration = FALSE, transform = c("NONE", "STANDARDIZE", "NORMALIZE", "DEMEAN", "DESCALE"), svd_method = c("GramSVD", "Power", "Randomized"), nv = 1, max_iterations = 1000, seed = -1, keep_u = TRUE, u_name = NULL, use_all_factor_levels = TRUE, max_runtime_secs = 0)character names of the predictors in the model.Logical. Ignore constant columns. Defaults to TRUE.Logical. Whether to score during each iteration of model training. Defaults to FALSE.Logical. Save left singular vectors? Defaults to TRUE.Logical. Whether first factor level is included in each categorical expansion Defaults to TRUE.
library(h2o)
h2o.init()
ausPath <- system.file("extdata", "australia.csv", package="h2o")
australia.hex <- h2o.uploadFile(path = ausPath)
h2o.svd(training_frame = australia.hex, nv = 8)
Run the code above in your browser using DataLab